==> jc-1.4.0.tar.gz: java/awt/image/CropImageFilter.h <==
// public class java.awt.image.CropImageFilter

// class file dependencies
// @dep_class 9becb4f603c823db java_awt_image_CropImageFilter
// @dep_class 9105d2ed83adb02b java_awt_image_ImageFilter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_image_ImageFilter

#include "java/awt/image/ImageFilter.h"

#ifndef _JC_java_awt_image_CropImageFilter_H_
#define _JC_java_awt_image_CropImageFilter_H_

// Forward structure declarations
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_java_awt_image_CropImageFilter$sub_refs	_jc_java_awt_image_CropImageFilter$sub_refs;
typedef struct _jc_java_awt_image_CropImageFilter$sub_nonrefs	_jc_java_awt_image_CropImageFilter$sub_nonrefs;
typedef struct _jc_java_awt_image_CropImageFilter$refs	_jc_java_awt_image_CropImageFilter$refs;
typedef struct _jc_java_awt_image_CropImageFilter$nonrefs	_jc_java_awt_image_CropImageFilter$nonrefs;
typedef struct _jc_java_awt_image_CropImageFilter$object	_jc_java_awt_image_CropImageFilter$object;

typedef const struct _jc_java_awt_image_CropImageFilter$vmethods	_jc_java_awt_image_CropImageFilter$vmethods;
typedef const struct _jc_java_awt_image_CropImageFilter$vtable	_jc_java_awt_image_CropImageFilter$vtable;
typedef const struct _jc_java_awt_image_CropImageFilter$vtype	_jc_java_awt_image_CropImageFilter$vtype;

// Constructors
extern void _jc_java_awt_image_CropImageFilter$method$_init$b5870f7bfece007a(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, jint, jint, jint, jint);

// Virtual methods
extern void _jc_java_awt_image_CropImageFilter$method$setDimensions$2a88308c71ee1b2d(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, jint, jint);
extern void _jc_java_awt_image_CropImageFilter$method$setPixels$8e6b1e7ca9838c65(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_java_awt_image_CropImageFilter$method$setPixels$07377c973c113c2c(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_int_array *, jint, jint);
extern void _jc_java_awt_image_CropImageFilter$method$setProperties$2406ca9c67a807f5(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, struct _jc_java_util_Hashtable$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_CropImageFilter$method_info$setDimensions$2a88308c71ee1b2d;
extern _jc_method _jc_java_awt_image_CropImageFilter$method_info$setPixels$8e6b1e7ca9838c65;
extern _jc_method _jc_java_awt_image_CropImageFilter$method_info$setPixels$07377c973c113c2c;
extern _jc_method _jc_java_awt_image_CropImageFilter$method_info$setProperties$2406ca9c67a807f5;

// Virtual methods structure
struct _jc_java_awt_image_CropImageFilter$vmethods {
	void	(*setDimensions$2a88308c71ee1b2d)(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, jint, jint);
	void	(*setPixels$8e6b1e7ca9838c65)(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_byte_array *, jint, jint);
	void	(*setPixels$07377c973c113c2c)(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_int_array *, jint, jint);
	void	(*setProperties$2406ca9c67a807f5)(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, struct _jc_java_util_Hashtable$object *);
};

// Vtable
struct _jc_java_awt_image_CropImageFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_ImageFilter$vmethods	java_awt_image_ImageFilter;
	_jc_java_awt_image_CropImageFilter$vmethods	java_awt_image_CropImageFilter;
};

// Vtype
struct _jc_java_awt_image_CropImageFilter$vtype {
	_jc_type			type;
	_jc_java_awt_image_CropImageFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_CropImageFilter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_image_CropImageFilter$refs {
    _jc_java_awt_image_CropImageFilter$sub_refs	java_awt_image_CropImageFilter;
    _jc_java_awt_image_ImageFilter$sub_refs	java_awt_image_ImageFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_CropImageFilter$sub_nonrefs {
	jint	x;
	jint	y;
	jint	width;
	jint	height;
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_CropImageFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_ImageFilter$sub_nonrefs	java_awt_image_ImageFilter;
    _jc_java_awt_image_CropImageFilter$sub_nonrefs	java_awt_image_CropImageFilter;
};

// Object instance structure
struct _jc_java_awt_image_CropImageFilter$object {
	_jc_java_awt_image_CropImageFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_CropImageFilter$vtype	*vtype;
	_jc_java_awt_image_CropImageFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_CropImageFilter$vtype _jc_java_awt_image_CropImageFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_CropImageFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_CropImageFilter$class_object;

#endif	/* _JC_java_awt_image_CropImageFilter_H_ */

==> jc-1.4.6.tar.gz: java/awt/image/CropImageFilter.h <==
// public class java.awt.image.CropImageFilter

// class file dependencies
// @dep_class 9becb4f603c823db java_awt_image_CropImageFilter
// @dep_class 9105d2ed83adb02b java_awt_image_ImageFilter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_image_ImageFilter

#include "java/awt/image/ImageFilter.h"

#ifndef _JC_java_awt_image_CropImageFilter_H_
#define _JC_java_awt_image_CropImageFilter_H_

// Forward structure declarations
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_java_awt_image_CropImageFilter$sub_refs	_jc_java_awt_image_CropImageFilter$sub_refs;
typedef struct _jc_java_awt_image_CropImageFilter$sub_nonrefs	_jc_java_awt_image_CropImageFilter$sub_nonrefs;
typedef struct _jc_java_awt_image_CropImageFilter$refs	_jc_java_awt_image_CropImageFilter$refs;
typedef struct _jc_java_awt_image_CropImageFilter$nonrefs	_jc_java_awt_image_CropImageFilter$nonrefs;
typedef struct _jc_java_awt_image_CropImageFilter$object	_jc_java_awt_image_CropImageFilter$object;

typedef const struct _jc_java_awt_image_CropImageFilter$vmethods	_jc_java_awt_image_CropImageFilter$vmethods;
typedef const struct _jc_java_awt_image_CropImageFilter$vtable	_jc_java_awt_image_CropImageFilter$vtable;
typedef const struct _jc_java_awt_image_CropImageFilter$vtype	_jc_java_awt_image_CropImageFilter$vtype;

// Constructors
extern void _jc_java_awt_image_CropImageFilter$method$_init$b5870f7bfece007a(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_image_CropImageFilter$method$setDimensions$2a88308c71ee1b2d(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_CropImageFilter$method$setPixels$8e6b1e7ca9838c65(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_CropImageFilter$method$setPixels$07377c973c113c2c(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_int_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_CropImageFilter$method$setProperties$2406ca9c67a807f5(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_CropImageFilter$method_info$setDimensions$2a88308c71ee1b2d;
extern _jc_method _jc_java_awt_image_CropImageFilter$method_info$setPixels$8e6b1e7ca9838c65;
extern _jc_method _jc_java_awt_image_CropImageFilter$method_info$setPixels$07377c973c113c2c;
extern _jc_method _jc_java_awt_image_CropImageFilter$method_info$setProperties$2406ca9c67a807f5;

// Virtual methods structure
struct _jc_java_awt_image_CropImageFilter$vmethods {
	void	(*setDimensions$2a88308c71ee1b2d)(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, jint, jint) _JC_JCNI_ATTR;
	void	(*setPixels$8e6b1e7ca9838c65)(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*setPixels$07377c973c113c2c)(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, jint, jint, jint, jint, struct _jc_java_awt_image_ColorModel$object *, struct _jc_int_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*setProperties$2406ca9c67a807f5)(_jc_env *, struct _jc_java_awt_image_CropImageFilter$object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_image_CropImageFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_ImageFilter$vmethods	java_awt_image_ImageFilter;
	_jc_java_awt_image_CropImageFilter$vmethods	java_awt_image_CropImageFilter;
};

// Vtype
struct _jc_java_awt_image_CropImageFilter$vtype {
	_jc_type			type;
	_jc_java_awt_image_CropImageFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_CropImageFilter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_image_CropImageFilter$refs {
    _jc_java_awt_image_CropImageFilter$sub_refs	java_awt_image_CropImageFilter;
    _jc_java_awt_image_ImageFilter$sub_refs	java_awt_image_ImageFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_CropImageFilter$sub_nonrefs {
	jint	x;
	jint	y;
	jint	width;
	jint	height;
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_CropImageFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_ImageFilter$sub_nonrefs	java_awt_image_ImageFilter;
    _jc_java_awt_image_CropImageFilter$sub_nonrefs	java_awt_image_CropImageFilter;
};

// Object instance structure
struct _jc_java_awt_image_CropImageFilter$object {
	_jc_java_awt_image_CropImageFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_CropImageFilter$vtype	*vtype;
	_jc_java_awt_image_CropImageFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_CropImageFilter$vtype _jc_java_awt_image_CropImageFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_CropImageFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_CropImageFilter$class_object;

#endif	/* _JC_java_awt_image_CropImageFilter_H_ */
